@@ -1,21 +1,20 @@
 package Egg::Model;
 #
-# Copyright 2006 Bee Flag, Corp. All Rights Reserved.
+# Copyright 2007 Bee Flag, Corp. All Rights Reserved.
 # Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
 #
-# $Id: Model.pm 99 2007-01-15 06:33:14Z lushe $
+# $Id: Model.pm 185 2007-02-17 07:18:18Z lushe $
 #
 use strict;
 use warnings;
-use base qw/Egg::AnyBase/;
+use base qw/Egg::Component/;
 
-our $VERSION= '0.03';
+our $VERSION= '0.04';
 
 1;
 
 __END__
 
-
 =head1 NAME
 
 Egg::Model - Common package for MODEL module.
@@ -30,11 +29,12 @@ Egg::Model - Common package for MODEL module.
 
 =head1 DESCRIPTION
 
-There is nothing now, too.
+This module has succeeded to Egg::Component.
 
 =head1 SEE ALSO
 
-L<Egg::Release>, L<Egg::Config>
+L<Egg::Component>,
+L<Egg::Release>,
 
 =head1 AUTHOR
 
@@ -42,7 +42,7 @@ Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 Bee Flag, Corp. E<lt>L<http://egg.bomcity.com/>E<gt>, All Rights Reserved.
+Copyright (C) 2007 Bee Flag, Corp. E<lt>L<http://egg.bomcity.com/>E<gt>, All Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
